<?php

namespace App\Http\Controllers;

use App\Models\Form;
use App\Models\Vendor;
use Illuminate\Http\Request;

class VendorController extends Controller
{
    public function index() {
        $vendors = Vendor::query()->latest()->get();
        return response()->json($vendors);
    }

    public function show($id) {
        $vendor = Vendor::findOrFail($id);
        return response()->json(['vendor' => $vendor]);
    }

    public function store(Request $request) {
        $validatedData = $request->validate([
            'name' => 'required|string',
            'email' => 'required|email',
            // 'logo' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
            'mobile_number' => 'required|string',
            // 'url' => 'nullable',
        ]);

        if ($request->hasFile('logo')) {
            $file = $request->file('logo');
            $filename = uniqid().'.'.$file->getClientOriginalExtension();
            $file->move(storage_path('app/public/logos'), $filename);
            $validatedData['logo'] = $filename;
        }

        $vendor = Vendor::create($request->all());

        return response()->json(['message' => 'Vendor created successfully', 'vendor' => $vendor], 201);
    }

    public function count() {
        $user = auth()->user(); // Get the authenticated user

        // Determine the user type and retrieve counts accordingly
        // dd($user->role == 'admin');
        if ($user->role == 'admin') {
            $allFormsCount = Form::count();
            $approveFormsCount = Form::where('status', '1')->count();
            $pendingApproveCount = Form::where('status', '0')->count();
        } elseif ($user->role == 'vendor') {
            $vendorFormsCount = Form::where('vendor_id', $user->vendor_id)->count();
            $vendorApproveFormsCount = Form::where('vendor_id', $user->vendor_id)->where('status', '1')->count();
            $vendorPendingApproveCount = Form::where('vendor_id', $user->vendor_id)->where('status', '0')->count();
        } else {
            // Handle other user types if needed
            return response()->json(['message' => 'Invalid user type'], 403);
        }

        return response()->json([
            'all_forms_count' => $allFormsCount ?? null,
            'approve_forms_count' => $approveFormsCount ?? null,
            'pending_approve_count' => $pendingApproveCount ?? null,
            'vendor_forms_count' => $vendorFormsCount ?? null,
            'vendor_approve_forms_count' => $vendorApproveFormsCount ?? null,
            'vendor_pending_approve_count' => $vendorPendingApproveCount ?? null,
        ]);
    }

    public function update(Request $request, $id) {
        $validatedData = $request->validate([
            'name' => 'required|string',
            'email' => 'required|email',
            // 'logo' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
            'mobile_number' => 'required|string',
            // 'url' => 'nullable',
        ]);

        $vendor = Vendor::findOrFail($id);

        if ($request->hasFile('logo')) {
            $file = $request->file('logo');
            $filename = uniqid().'.'.$file->getClientOriginalExtension();
            $file->move(storage_path('app/public/logos'), $filename);
            $vendor->logo = $filename;
        }

        $vendor->name = $request->name;
        $vendor->email = $request->email;
        $vendor->mobile_number = $request->mobile_number;
        $vendor->url = $request->url;
        $vendor->update();
        // $vendor->update($request->all());

        return response()->json(['message' => 'Vendor updated successfully', 'vendor' => $vendor]);
    }

    public function delete(Request $request, $id) {
        // Logic to delete a vendor by ID
        $vendor = Vendor::find($id);

        if (!$vendor) {
            return response()->json(['error' => 'Vendor not found'], 404);
        }

        $vendor->delete();

        return response()->json(['message' => 'Vendor deleted successfully']);
    }
}
